@@ -9,7 +9,7 @@ use base 'DBIx::Custom::Model';
 sub insert {
     my ($self, $param) = @_;
     
-    return $self->SUPER::insert($param);
+    return $self->SUPER::insert(param => $param);
 }
 
 sub list { shift->select; }
